nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

PllSicClr

Struct PllSicClr 

#[repr(transparent)]
pub struct PllSicClr(pub u32);
USB PHY PLL Control/Status Register

Tuple Fields

0: u32

Implementations

Source

impl PllSicClr

pub const fn pll_en_usb_clks(&self) -> bool

Enables the USB clock from PLL to USB PHY

pub const fn set_pll_en_usb_clks(&mut self, val: bool)

Enables the USB clock from PLL to USB PHY

pub const fn pll_power(&self) -> bool

Power up the USB PLL

pub const fn set_pll_power(&mut self, val: bool)

Power up the USB PLL

pub const fn pll_enable(&self) -> bool

Enables the clock output from the USB PLL

pub const fn set_pll_enable(&mut self, val: bool)

Enables the clock output from the USB PLL

pub const fn refbias_pwd_sel(&self) -> PllSicClrRefbiasPwdSel

Reference bias power down select.

pub const fn set_refbias_pwd_sel(&mut self, val: PllSicClrRefbiasPwdSel)

Reference bias power down select.

pub const fn refbias_pwd(&self) -> bool

Power down the reference bias This bit is only used when REFBIAS_PWD_SEL is set to 1.

pub const fn set_refbias_pwd(&mut self, val: bool)

Power down the reference bias This bit is only used when REFBIAS_PWD_SEL is set to 1.

pub const fn pll_reg_enable(&self) -> bool

This field controls the USB PLL regulator, set to enable the regulator

pub const fn set_pll_reg_enable(&mut self, val: bool)

This field controls the USB PLL regulator, set to enable the regulator

pub const fn pll_div_sel(&self) -> PllSicClrPllDivSel

This field controls the USB PLL feedback loop divider

pub const fn set_pll_div_sel(&mut self, val: PllSicClrPllDivSel)

This field controls the USB PLL feedback loop divider

pub const fn pll_prediv(&self) -> bool

This is selection between /1 or /2 to expand the range of ref input clock.

pub const fn set_pll_prediv(&mut self, val: bool)

This is selection between /1 or /2 to expand the range of ref input clock.

pub const fn pll_lock(&self) -> PllSicClrPllLock

USB PLL lock status indicator

pub const fn set_pll_lock(&mut self, val: PllSicClrPllLock)

USB PLL lock status indicator