#[repr(transparent)]pub struct Rx(pub u32);Expand description
USB PHY Receiver Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Rx
impl Rx
Sourcepub const fn envadj(&self) -> RxEnvadj
pub const fn envadj(&self) -> RxEnvadj
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn set_envadj(&mut self, val: RxEnvadj)
pub const fn set_envadj(&mut self, val: RxEnvadj)
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn disconadj(&self) -> RxDisconadj
pub const fn disconadj(&self) -> RxDisconadj
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn set_disconadj(&mut self, val: RxDisconadj)
pub const fn set_disconadj(&mut self, val: RxDisconadj)
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn rxdbypass(&self) -> RxRxdbypass
pub const fn rxdbypass(&self) -> RxRxdbypass
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver
Sourcepub const fn set_rxdbypass(&mut self, val: RxRxdbypass)
pub const fn set_rxdbypass(&mut self, val: RxRxdbypass)
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver