#[repr(transparent)]pub struct RxSet(pub u32);Expand description
USB PHY Receiver Control Register
Tuple Fields
0: u32Implementations
Sourceimpl RxSet
impl RxSet
Sourcepub const fn envadj(&self) -> RxSetEnvadj
pub const fn envadj(&self) -> RxSetEnvadj
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn set_envadj(&mut self, val: RxSetEnvadj)
pub const fn set_envadj(&mut self, val: RxSetEnvadj)
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn disconadj(&self) -> RxSetDisconadj
pub const fn disconadj(&self) -> RxSetDisconadj
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn set_disconadj(&mut self, val: RxSetDisconadj)
pub const fn set_disconadj(&mut self, val: RxSetDisconadj)
The DISCONADJ field adjusts the trip point for the disconnect detector.
Sourcepub const fn rxdbypass(&self) -> RxSetRxdbypass
pub const fn rxdbypass(&self) -> RxSetRxdbypass
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver
Sourcepub const fn set_rxdbypass(&mut self, val: RxSetRxdbypass)
pub const fn set_rxdbypass(&mut self, val: RxSetRxdbypass)
This test mode is intended for lab use only, replace FS differential receiver with DP single ended receiver