nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Status

Struct Status 

#[repr(transparent)]
pub struct Status(pub u32);
USB PHY Status Register

Tuple Fields

0: u32

Implementations

Source

impl Status

pub const fn ok_status_3v(&self) -> bool

Indicates the USB 3v power rails are in range.

pub const fn set_ok_status_3v(&mut self, val: bool)

Indicates the USB 3v power rails are in range.

pub const fn hostdiscondetect_status(&self) -> HostdiscondetectStatus

Indicates at the local host (downstream) port that the remote device has disconnected while in High-Speed mode

pub const fn set_hostdiscondetect_status(&mut self, val: HostdiscondetectStatus)

Indicates at the local host (downstream) port that the remote device has disconnected while in High-Speed mode

pub const fn devplugin_status(&self) -> DevpluginStatus

Status indicator for non-standard resistive plugged-in detection Indicates that the device has been connected on the USB_DP and USB_DM lines using the nonstandard resistive plugged-in detection method controlled by CTRL[4]

pub const fn set_devplugin_status(&mut self, val: DevpluginStatus)

Status indicator for non-standard resistive plugged-in detection Indicates that the device has been connected on the USB_DP and USB_DM lines using the nonstandard resistive plugged-in detection method controlled by CTRL[4]

pub const fn resume_status(&self) -> bool

Indicates that the host is sending a wake-up after Suspend and has triggered an interrupt.

pub const fn set_resume_status(&mut self, val: bool)

Indicates that the host is sending a wake-up after Suspend and has triggered an interrupt.